===================================================
django-content-editor -- Editing structured content
===================================================

`Documentation on Read the Docs <http://django-content-editor.readthedocs.org/en/latest/>`_

.. image:: https://travis-ci.org/matthiask/django-content-editor.svg?branch=master
    :target: https://travis-ci.org/matthiask/django-content-editor
